@@ -1,11 +1,12 @@
 from pygpe.shared.grid import Grid
+from pygpe.shared.wavefunction import _Wavefunction
 import cupy as cp
 
 
-class Wavefunction:
+class ScalarWavefunction(_Wavefunction):
     """Represents the scalar BEC wavefunction.
-    This class contains the wavefunction array, in addition to various useful functions for manipulating and using the
-    wavefunction.
+    This class contains the wavefunction array, in addition to various useful
+    functions for manipulating and using the wavefunction.
 
     :param grid: The numerical grid.
     :type grid: :class:`Grid`
@@ -18,7 +19,7 @@ class Wavefunction:
 
     def __init__(self, grid: Grid):
         """Constructs the wavefunction object."""
-        self.grid = grid
+        super().__init__(grid)
 
         self.component = cp.empty(grid.shape, dtype="complex128")
         self.fourier_component = cp.empty(
@@ -44,17 +45,9 @@ class Wavefunction:
         :param std_dev: The standard deviation of the normal distribution.
         :type std_dev: float
         """
-        self.component += self._generate_complex_normal_dist(mean, std_dev)
+        self.component += super()._generate_complex_normal_dist(mean, std_dev)
         self._update_atom_number()
 
-    def _generate_complex_normal_dist(self, mean: float, std_dev: float) -> cp.ndarray:
-        """Returns a ndarray of complex values containing results from
-        a normal distribution.
-        """
-        return cp.random.normal(
-            mean, std_dev, size=self.grid.shape
-        ) + 1j * cp.random.normal(mean, std_dev, size=self.grid.shape)
-
     def apply_phase(self, phase: cp.ndarray) -> None:
         """Applies a phase to the wavefunction.
 
@@ -69,11 +62,15 @@ class Wavefunction:
         )
 
     def fft(self) -> None:
-        """Fourier transforms real-space component and updates Fourier-space component."""
+        """Fourier transforms real-space component and updates Fourier-space
+        component.
+        """
         self.fourier_component = cp.fft.fftn(self.component)
 
     def ifft(self) -> None:
-        """Inverse Fourier transforms Fourier-space component and updates real-space component."""
+        """Inverse Fourier transforms Fourier-space component and updates
+        real-space component.
+        """
         self.component = cp.fft.ifftn(self.fourier_component)
 
     def density(self) -> cp.ndarray:
