@@ -2,7 +2,9 @@ import numpy as np
 from pygpe.shared.grid import Grid
 
 
-def _generate_positions(grid: Grid, num_vortices: int, threshold: float) -> iter:
+def _generate_positions(
+    grid: Grid, num_vortices: int, threshold: float
+) -> iter:
     """Generates and returns a list of positions that are separated by at least
     `threshold`.
     """
@@ -28,15 +30,18 @@ def _generate_positions(grid: Grid, num_vortices: int, threshold: float) -> iter
 
         iterations += 1
 
-    print(f"Successfully found {num_vortices} positions in {iterations} iterations!")
+    print(
+        f"Successfully found {num_vortices} positions "
+        "in {iterations} iterations!"
+    )
     return iter(vortex_positions)
 
 
 def _position_sufficiently_far(
     position: tuple, accepted_positions: list[tuple], threshold: float
 ) -> bool:
-    """Tests that the given `position` is at least `threshold` away from all the positions
-    currently in `accepted_positions`.
+    """Tests that the given `position` is at least `threshold` away from all
+    the positions currently in `accepted_positions`.
     """
     # Special case where accepted_positions is empty
     if not accepted_positions:
@@ -50,17 +55,23 @@ def _position_sufficiently_far(
 
 
 def _heaviside(array: np.ndarray) -> np.ndarray:
-    """Computes the heaviside function on a given array and returns the result."""
+    """Computes the heaviside function on a given array and returns the
+    result.
+    """
     return np.where(array < 0, np.zeros(array.shape), np.ones(array.shape))
 
 
-def vortex_phase_profile(grid: Grid, num_vortices: int, threshold: float) -> np.ndarray:
+def vortex_phase_profile(
+    grid: Grid, num_vortices: int, threshold: float
+) -> np.ndarray:
     """Constructs a 2D phase profile consisting of 2pi phase windings.
-    This phase can be applied to a wavefunction to generate different types of vortices.
+    This phase can be applied to a wavefunction to generate different types of
+    vortices.
 
     :param grid: The 2D grid of the system.
     :type grid: :class:`Grid`
-    :param num_vortices: The total number of vortices to be included in the phase profile.
+    :param num_vortices: The total number of vortices to be included in the
+        phase profile.
     :type num_vortices: int
     :param threshold: The minimum distance allowed between any two vortices.
     :type threshold: float
@@ -70,7 +81,9 @@ def vortex_phase_profile(grid: Grid, num_vortices: int, threshold: float) -> np.
     phase = np.zeros((grid.num_points_x, grid.num_points_y), dtype="float32")
 
     for _ in range(num_vortices // 2):
-        phase_temp = np.zeros((grid.num_points_x, grid.num_points_y), dtype="float32")
+        phase_temp = np.zeros(
+            (grid.num_points_x, grid.num_points_y), dtype="float32"
+        )
         x_pos_minus, y_pos_minus = next(
             vortex_positions_iter
         )  # Negative circulation vortex
