@@ -2,11 +2,12 @@ import h5py
 import cupy as cp
 from pygpe.shared.grid import Grid
 from pygpe.shared import data_manager_paths as dmp
-from pygpe.spinhalf.wavefunction import Wavefunction
+from pygpe.spinhalf.wavefunction import SpinHalfWavefunction
 
 
 class DataManager:
-    """This object handles all the data of the simulation, including the wavefunction, grid, and parameter data.
+    """This object handles all the data of the simulation, including the
+    wavefunction, grid, and parameter data.
 
     :param filename: The name of the data file.
     :type filename: str
@@ -26,7 +27,7 @@ class DataManager:
         h5py.File(f"{self.data_path}/{self.filename}", "w")
 
     def save_initial_parameters(
-        self, grid: Grid, wfn: Wavefunction, parameters: dict
+        self, grid: Grid, wfn: SpinHalfWavefunction, parameters: dict
     ) -> None:
         """Saves the initial grid, wavefunction and parameters to a HDF5 file.
 
@@ -38,7 +39,10 @@ class DataManager:
         :type parameters: dict
         """
         if grid.ndim > 3 or grid.ndim < 1:
-            raise ValueError(f"Grid with dimension of {grid.ndim} is unsupported, please use a 1D, 2D, or 3D grid.")
+            raise ValueError(
+                f"Grid with dimension of {grid.ndim} is unsupported, "
+                "please use a 1D, 2D, or 3D grid."
+            )
         self._save_initial_grid_params(grid)
         self._save_initial_wfn(wfn)
         self._save_params(parameters)
@@ -64,7 +68,7 @@ class DataManager:
                 file.create_dataset(dmp.GRID_DY, data=grid.grid_spacing_y)
                 file.create_dataset(dmp.GRID_DZ, data=grid.grid_spacing_z)
 
-    def _save_initial_wfn(self, wfn: Wavefunction) -> None:
+    def _save_initial_wfn(self, wfn: SpinHalfWavefunction) -> None:
         """Creates new datasets in file for the wavefunction and saves
         initial values.
         """
@@ -104,7 +108,7 @@ class DataManager:
             for key in parameters:
                 file.create_dataset(f"parameters/{key}", data=parameters[key])
 
-    def save_wavefunction(self, wfn: Wavefunction) -> None:
+    def save_wavefunction(self, wfn: SpinHalfWavefunction) -> None:
         """Saves the current wavefunction data to the dataset.
 
         :param wfn: The wavefunction of the system.
@@ -114,19 +118,31 @@ class DataManager:
         with h5py.File(f"{self.data_path}/{self.filename}", "r+") as data:
             if wfn.grid.ndim == 1:
                 new_psi_plus = data[dmp.SPINHALF_WAVEFUNCTION_PLUS]
-                new_psi_plus.resize((wfn.grid.num_points_x, self._time_index + 1))
-                new_psi_plus[:, self._time_index] = cp.asnumpy(wfn.plus_component)
+                new_psi_plus.resize(
+                    (wfn.grid.num_points_x, self._time_index + 1)
+                )
+                new_psi_plus[:, self._time_index] = cp.asnumpy(
+                    wfn.plus_component
+                )
 
                 new_psi_minus = data[dmp.SPINHALF_WAVEFUNCTION_MINUS]
-                new_psi_minus.resize((wfn.grid.num_points_x, self._time_index + 1))
-                new_psi_minus[:, self._time_index] = cp.asnumpy(wfn.minus_component)
+                new_psi_minus.resize(
+                    (wfn.grid.num_points_x, self._time_index + 1)
+                )
+                new_psi_minus[:, self._time_index] = cp.asnumpy(
+                    wfn.minus_component
+                )
             else:
                 new_psi_plus = data[dmp.SPINHALF_WAVEFUNCTION_PLUS]
                 new_psi_plus.resize((*wfn.grid.shape, self._time_index + 1))
-                new_psi_plus[..., self._time_index] = cp.asnumpy(wfn.plus_component)
+                new_psi_plus[..., self._time_index] = cp.asnumpy(
+                    wfn.plus_component
+                )
 
                 new_psi_minus = data[dmp.SPINHALF_WAVEFUNCTION_MINUS]
                 new_psi_minus.resize((*wfn.grid.shape, self._time_index + 1))
-                new_psi_minus[..., self._time_index] = cp.asnumpy(wfn.minus_component)
+                new_psi_minus[..., self._time_index] = cp.asnumpy(
+                    wfn.minus_component
+                )
 
         self._time_index += 1
