@@ -1,8 +1,8 @@
 import cupy as cp
-from pygpe.spintwo.wavefunction import Wavefunction
+from pygpe.spintwo.wavefunction import SpinTwoWavefunction
 
 
-def step_wavefunction(wfn: Wavefunction, params: dict) -> None:
+def step_wavefunction(wfn: SpinTwoWavefunction, params: dict) -> None:
     """Propagates the wavefunction forward one time step.
 
     :param wfn: The wavefunction of the system.
@@ -19,20 +19,30 @@ def step_wavefunction(wfn: Wavefunction, params: dict) -> None:
         _renormalise_wavefunction(wfn)
 
 
-def _kinetic_step(wfn: Wavefunction, pm: dict) -> None:
+def _kinetic_step(wfn: SpinTwoWavefunction, pm: dict) -> None:
     """Computes the kinetic energy subsystem for half a time step.
 
     :param wfn: The wavefunction of the system.
     :param pm:  The parameters' dictionary.
     """
-    wfn.fourier_plus2_component *= cp.exp(-0.25 * 1j * pm["dt"] * wfn.grid.wave_number)
-    wfn.fourier_plus1_component *= cp.exp(-0.25 * 1j * pm["dt"] * wfn.grid.wave_number)
-    wfn.fourier_zero_component *= cp.exp(-0.25 * 1j * pm["dt"] * wfn.grid.wave_number)
-    wfn.fourier_minus1_component *= cp.exp(-0.25 * 1j * pm["dt"] * wfn.grid.wave_number)
-    wfn.fourier_minus2_component *= cp.exp(-0.25 * 1j * pm["dt"] * wfn.grid.wave_number)
+    wfn.fourier_plus2_component *= cp.exp(
+        -0.25 * 1j * pm["dt"] * wfn.grid.wave_number
+    )
+    wfn.fourier_plus1_component *= cp.exp(
+        -0.25 * 1j * pm["dt"] * wfn.grid.wave_number
+    )
+    wfn.fourier_zero_component *= cp.exp(
+        -0.25 * 1j * pm["dt"] * wfn.grid.wave_number
+    )
+    wfn.fourier_minus1_component *= cp.exp(
+        -0.25 * 1j * pm["dt"] * wfn.grid.wave_number
+    )
+    wfn.fourier_minus2_component *= cp.exp(
+        -0.25 * 1j * pm["dt"] * wfn.grid.wave_number
+    )
 
 
-def _interaction_step(wfn: Wavefunction, pm: dict) -> None:
+def _interaction_step(wfn: SpinTwoWavefunction, pm: dict) -> None:
     # Calculate density and singlets
     n = _density(wfn)
     a20 = _singlet_duo(wfn)
@@ -85,7 +95,7 @@ def _interaction_step(wfn: Wavefunction, pm: dict) -> None:
     wfn.minus2_component = temp_wfn[4]
 
 
-def _density(wfn: Wavefunction) -> cp.ndarray:
+def _density(wfn: SpinTwoWavefunction) -> cp.ndarray:
     return (
         abs(wfn.plus2_component) ** 2
         + abs(wfn.plus1_component) ** 2
@@ -95,7 +105,7 @@ def _density(wfn: Wavefunction) -> cp.ndarray:
     )
 
 
-def _singlet_duo(wfn: Wavefunction) -> cp.ndarray:
+def _singlet_duo(wfn: SpinTwoWavefunction) -> cp.ndarray:
     return (
         1
         / cp.sqrt(5)
@@ -108,7 +118,7 @@ def _singlet_duo(wfn: Wavefunction) -> cp.ndarray:
 
 
 def _evolve_spin_singlet(
-    wfn: Wavefunction, dens: cp.ndarray, singlet: cp.ndarray, pm: dict
+    wfn: SpinTwoWavefunction, dens: cp.ndarray, singlet: cp.ndarray, pm: dict
 ) -> list[cp.ndarray]:
     s = cp.nan_to_num(cp.sqrt(dens**2 - abs(singlet) ** 2))
     cos_term = cp.cos(pm["c4"] * s * pm["dt"])
@@ -118,13 +128,19 @@ def _evolve_spin_singlet(
     psi_p2 = (
         wfn.plus2_component * cos_term
         + 1j
-        * (dens * wfn.plus2_component - singlet * cp.conj(wfn.minus2_component))
+        * (
+            dens * wfn.plus2_component
+            - singlet * cp.conj(wfn.minus2_component)
+        )
         * sin_term
     )
     psi_p1 = (
         wfn.plus1_component * cos_term
         + 1j
-        * (dens * wfn.plus1_component + singlet * cp.conj(wfn.minus1_component))
+        * (
+            dens * wfn.plus1_component
+            + singlet * cp.conj(wfn.minus1_component)
+        )
         * sin_term
     )
     psi_0 = (
@@ -136,13 +152,19 @@ def _evolve_spin_singlet(
     psi_m1 = (
         wfn.minus1_component * cos_term
         + 1j
-        * (dens * wfn.minus1_component + singlet * cp.conj(wfn.plus1_component))
+        * (
+            dens * wfn.minus1_component
+            + singlet * cp.conj(wfn.plus1_component)
+        )
         * sin_term
     )
     psi_m2 = (
         wfn.minus2_component * cos_term
         + 1j
-        * (dens * wfn.minus2_component - singlet * cp.conj(wfn.plus2_component))
+        * (
+            dens * wfn.minus2_component
+            - singlet * cp.conj(wfn.plus2_component)
+        )
         * sin_term
     )
 
@@ -150,10 +172,14 @@ def _evolve_spin_singlet(
 
 
 def _calculate_spin_vectors(wfn: list[cp.ndarray]):
-    fp = cp.sqrt(6) * (wfn[1] * cp.conj(wfn[2]) + wfn[2] * cp.conj(wfn[3])) + 2 * (
-        wfn[3] * cp.conj(wfn[4]) + wfn[0] * cp.conj(wfn[1])
+    fp = cp.sqrt(6) * (
+        wfn[1] * cp.conj(wfn[2]) + wfn[2] * cp.conj(wfn[3])
+    ) + 2 * (wfn[3] * cp.conj(wfn[4]) + wfn[0] * cp.conj(wfn[1]))
+    fz = (
+        2 * (abs(wfn[0]) ** 2 - abs(wfn[4]) ** 2)
+        + abs(wfn[1]) ** 2
+        - abs(wfn[3]) ** 2
     )
-    fz = 2 * (abs(wfn[0]) ** 2 - abs(wfn[4]) ** 2) + abs(wfn[1]) ** 2 - abs(wfn[3]) ** 2
     return fp, fz
 
 
@@ -184,7 +210,7 @@ def _calc_qpsi(fz, fp, wfn):
     return qpsi
 
 
-def _renormalise_wavefunction(wfn: Wavefunction) -> None:
+def _renormalise_wavefunction(wfn: SpinTwoWavefunction) -> None:
     """Re-normalises the wavefunction to the correct atom number.
 
     :param wfn: The wavefunction of the system.
@@ -212,12 +238,14 @@ def _renormalise_wavefunction(wfn: Wavefunction) -> None:
     wfn.fft()
 
 
-def _calculate_atom_num(wfn: Wavefunction) -> tuple[int, int, int, int, int]:
+def _calculate_atom_num(
+    wfn: SpinTwoWavefunction,
+) -> tuple[int, int, int, int, int]:
     """Calculates the atom number of each wavefunction component.
 
     :param wfn: The wavefunction of the system.
-    :return: The atom numbers of the plus two, plus one, zero, minus one, and minus two
-    components, respectively.
+    :return: The atom numbers of the plus two, plus one, zero, minus one, and
+        minus two components, respectively.
     """
     atom_num_plus2 = wfn.grid.grid_spacing_product * cp.sum(
         cp.abs(wfn.plus2_component) ** 2
